@@ -1,15 +1,17 @@
 from __future__ import annotations
 from typing import Any, NamedTuple, TypeVar, Union, cast, TYPE_CHECKING
 from datetime import datetime
-from inflection import camelize
 from bson.objectid import ObjectId
 from jsonclasses.jfield import JField
 from jsonclasses.fdef import FStore, FType
 from jsonclasses.keypath import concat_keypath
 from jsonclasses.mgraph import MGraph
 from jsonclasses.types import types
+from inflection import camelize
 from .coder import Coder
-from .utils import ref_db_field_key, ref_db_field_keys, ref_field_key
+from .utils import (
+    ref_db_field_key, ref_db_field_keys, ref_field_key
+)
 from .context import EncodingContext
 from .command import (Command, InsertOneCommand, UpdateOneCommand,
                       UpsertOneCommand, DeleteOneCommand, BatchCommand)
@@ -262,7 +264,9 @@ class Encoder(Coder):
                     keypath_parent=fname,
                     parent=value))
                 if use_insert_command or fname in fields_need_update:
-                    id_list = [result['_id'] for result in item_result]
+                    tsfm = value.__class__.cdef.jconf.ref_key_encoding_strategy
+                    field_id_name = tsfm(field)
+                    id_list = [ObjectId(v) for v in getattr(value, field_id_name)]
                     fname_ref = ref_db_field_keys(fname, cls)
                     if use_insert_command:
                         result_set[fname_ref] = id_list
